@@ -23,52 +23,52 @@
 package Ftree::FamilyTreeDataFactory;
 use strict;
 use warnings;
-use version; our $VERSION = qv('2.3.36');
-
-use Switch;
+use version; our $VERSION = qv('2.3.37');
+use v5.10.1;
+use experimental 'smartmatch';
 
 sub getFamilyTree {
 	my ($config) = @_;
 	my $type = $config->{type};
 	$type = 'csv' if ( $type eq 'txt' );
 
-	switch ($type) {
-		case 'csv' {
+	given ($type) {
+		when (/\bcsv\b/) {
 			require Ftree::DataParsers::ExtendedSimonWardFormat;
 			return
 			  Ftree::DataParsers::ExtendedSimonWardFormat::createFamilyTreeDataFromFile(
 				$config->{config} );
 		}
-		case 'excel' {
+		when (/\bexcel\b/) {
 			require Ftree::DataParsers::ExcelFormat;
 			return
 			  Ftree::DataParsers::ExcelFormat::createFamilyTreeDataFromFile(
 				$config->{config} );
 		}
-		case 'excelx' {
+		when (/\bexcelx\b/) {
 			require Ftree::DataParsers::ExcelxFormat;
 			return
 			  Ftree::DataParsers::ExcelxFormat::createFamilyTreeDataFromFile(
 				$config->{config} );
 		}
-		case 'ser' {
+		when (/\bser\b/) {
 			require Ftree::DataParsers::SerializerFormat;
 			return
 			  Ftree::DataParsers::SerializerFormat::createFamilyTreeDataFromFile(
 				$config->{config} );
 		}
-		case 'gedcom' {
+		when (/\bgedcom\b/) {
 			require Ftree::DataParsers::GedcomFormat;
 			return
 			  Ftree::DataParsers::GedcomFormat::createFamilyTreeDataFromFile(
 				$config->{config} );
 		}
-		case 'dbi' {
+		when (/\bdbi\b/) {
 			require Ftree::DataParsers::DBIFormat;
 			return Ftree::DataParsers::DBIFormat::getFamilyTreeData(
 				$config->{config} );
 		}
-		else { die "Unknown type: $type" }
+		default { die "Unknown type: $type" }
 	}
 
 	return;
