@@ -26,7 +26,7 @@ package Ftree::Name;
 use strict;
 use warnings;
 use Ftree::TextGeneratorFactory qw(getTextGenerator get_reverse_name);
-use version; our $VERSION = qv('2.3.36');
+use version; our $VERSION = qv('2.3.37');
 
 use Params::Validate qw(:all);
 
@@ -127,7 +127,7 @@ installator for Windows 7 32bit
 L<https://sourceforge.net/projects/family-tree-32/files/latest/download?source=navbar>
 
   #If install it
-  cpanm M/MI/MISHIN/FamilyTreeInfo-2.3.33.tar.gz
+  cpanm FamilyTreeInfo
 
   git clone https://github.com/mishin/Ftree-cpan.git
   cd Ftree-cpan/cgi-bin
