@@ -25,7 +25,7 @@ use strict;
 use warnings;
 
 use version;
-our $VERSION = qv('2.3.36');
+our $VERSION = qv('2.3.37');
 
 use Ftree::FamilyTreeBase;
 use Sub::Exporter -setup => { exports => [ qw(new main) ] };
@@ -132,7 +132,7 @@ sub _draw_pictures {
 
 sub _draw_single_person_page {
     my ($self) = validate_pos( @_, { type => HASHREF } );
-    binmode STDOUT, ":utf8";
+    binmode STDOUT, ":encoding(UTF-8)";
     $self->_toppage( $self->{target_person}->get_name()->get_long_name() );
 
     print $q->start_center;
